==> haskell-glob-0.9.2-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-glob.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: Glob
version: 0.9.2
id: Glob-0.9.2-5yb38ydyVE42JmysXCdmSi
key: Glob-0.9.2-5yb38ydyVE42JmysXCdmSi
license: BSD-3-Clause
maintainer: Matti Niemenmaa <matti.niemenmaa+glob@iki.fi>
author: Matti Niemenmaa
stability: provisional
homepage: http://iki.fi/matti.niemenmaa/glob/
synopsis: Globbing library
description:
    A library for globbing: matching patterns against file paths.
category: System
abi: 2e0c28767328ce383047b3d3d84ba8bf
exposed: True
exposed-modules:
    System.FilePath.Glob System.FilePath.Glob.Primitive
hidden-modules: System.FilePath.Glob.Base
                System.FilePath.Glob.Directory System.FilePath.Glob.Match
                System.FilePath.Glob.Simplify System.FilePath.Glob.Utils
import-dirs: /usr/lib/ghc-8.4.3/site-local/Glob-0.9.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/Glob-0.9.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/Glob-0.9.2
hs-libraries: HSGlob-0.9.2-5yb38ydyVE42JmysXCdmSi
depends:
    base-4.11.1.0 containers-0.5.11.0 directory-1.3.1.5
    dlist-0.8.0.4-CrGJIvQnsM82JxkEwejrYD filepath-1.4.2
    transformers-0.5.5.0
    transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             dlist-0.8.0.4-CrGJIvQnsM82JxkEwejrYD=f79b3ead594e04b4f22b6b2afc0a8656
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W=8fe746d31ebcf312c14c2777ca0f137c
haddock-interfaces: /usr/share/doc/haskell-glob/html/Glob.haddock
haddock-html: /usr/share/doc/haskell-glob/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-glob-0.9.2-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-glob.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: Glob
version: 0.9.2
id: Glob-0.9.2-Gzh2LJD3qq97wreFxSv5l5
key: Glob-0.9.2-Gzh2LJD3qq97wreFxSv5l5
license: BSD-3-Clause
maintainer: Matti Niemenmaa <matti.niemenmaa+glob@iki.fi>
author: Matti Niemenmaa
stability: provisional
homepage: http://iki.fi/matti.niemenmaa/glob/
synopsis: Globbing library
description:
    A library for globbing: matching patterns against file paths.
category: System
abi: cb729a361a66d7bc498a592966b6cd8c
exposed: True
exposed-modules:
    System.FilePath.Glob System.FilePath.Glob.Primitive
hidden-modules: System.FilePath.Glob.Base
                System.FilePath.Glob.Directory System.FilePath.Glob.Match
                System.FilePath.Glob.Simplify System.FilePath.Glob.Utils
import-dirs: /usr/lib/ghc-8.4.3/site-local/Glob-0.9.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/Glob-0.9.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/Glob-0.9.2
hs-libraries: HSGlob-0.9.2-Gzh2LJD3qq97wreFxSv5l5
depends:
    base-4.11.1.0 containers-0.5.11.0 directory-1.3.1.5
    dlist-0.8.0.4-CrGJIvQnsM82JxkEwejrYD filepath-1.4.2
    transformers-0.5.5.0
    transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             dlist-0.8.0.4-CrGJIvQnsM82JxkEwejrYD=f79b3ead594e04b4f22b6b2afc0a8656
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W=8fe746d31ebcf312c14c2777ca0f137c
haddock-interfaces: /usr/share/doc/haskell-glob/html/Glob.haddock
haddock-html: /usr/share/doc/haskell-glob/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
